[GitHub Pages](https://amerenicenter.github.io/snake2/)

# snake2

# Installing

## Option 1
**Install via pip**
```
pip install icenter_snake2
```

## Option 2
**Clone the GitHub repository**
```
git clone https://github.com/AmerenICenter/snake2.git
```

# Usage

## Option 1
**Run the main script from terminal**
```
python snake_main.py
```

## Option 2
**Run as a module from terminal**
```
python -m snake2
```
*Note: this calls `src/__main__.py`*

## Option 3
**Import the package within a python script**
```python
import snake2
snake2.run()
```


# Authors

